==> glpi-11.0.2.tgz: glpi/src/Glpi/Form/Condition/ConditionableVisibilityInterface.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

namespace Glpi\Form\Condition;

interface ConditionableVisibilityInterface extends ConditionableInterface
{
    /**
     * Get the configured visibility strategy from the database.
     *
     * @return VisibilityStrategy
     */
    public function getConfiguredVisibilityStrategy(): VisibilityStrategy;

    /**
     * Get the UUID of the item.
     *
     * @return string
     */
    public function getUUID(): string;
}

==> glpi-11.0.4.tgz: glpi/src/Glpi/Form/Condition/ConditionableVisibilityInterface.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

namespace Glpi\Form\Condition;

interface ConditionableVisibilityInterface extends ConditionableInterface
{
    /**
     * Get the configured visibility strategy from the database.
     *
     * @return VisibilityStrategy
     */
    public function getConfiguredVisibilityStrategy(): VisibilityStrategy;

    /**
     * Get the UUID of the item.
     *
     * @return string
     */
    public function getUUID(): string;

    // TODO: uncomment on main to prevent BC breaks
    // protected function removeSavedConditionsIfAlwaysVisible(array $input): array;
}
